@@ -1,4 +1,4 @@
-/*  $Id: ckpasswd.c,v 1.6.2.3 2001/07/19 21:28:13 rra Exp $
+/*  $Id: ckpasswd.c,v 1.6.2.4 2002/09/26 23:12:11 rra Exp $
 **
 **  The default username/password authenticator.
 */
@@ -18,8 +18,12 @@
 # ifdef HAVE_NDBM_H
 #  include <ndbm.h>
 # else
-#  ifdef HAVE_DB1_NDBM_H
-#   include <db1/ndbm.h>
+#  ifdef HAVE_GDBM_NDBM_H
+#   include <gdbm-ndbm.h>
+#  else
+#   ifdef HAVE_DB1_NDBM_H
+#    include <db1/ndbm.h>
+#   endif
 #  endif
 # endif
 #endif
