@@ -1,4 +1,4 @@
-/*  $Id: inews.c,v 1.27.2.4 2000/11/16 06:10:21 rra Exp $
+/*  $Id: inews.c,v 1.27.2.5 2003/02/02 20:27:58 rra Exp $
 **
 **  Send an article (prepared by someone on the local site) to the
 **  master news server.
@@ -568,7 +568,7 @@ FormatUserName(pwp, node)
 STATIC void CheckDistribution(char *p)
 {
     static char		SEPS[] = " \t,";
-    register STRING	**dp;
+    register STRING	*dp;
 
     if ((p = strtok(p, SEPS)) == NULL) {
 	(void)fprintf(stderr, "Can't parse Distribution line.\n");
