@@ -1,4 +1,4 @@
-/*  $Id: cc.c,v 1.70.2.3 2002/10/05 21:52:05 rra Exp $
+/*  $Id: cc.c,v 1.70.2.4 2003/02/02 20:46:54 rra Exp $
 **
 **  Routines for the control channel.  Create a Unix-domain datagram socket
 **  that processes on the local server send messages to.  The control
@@ -955,7 +955,7 @@ CCname(char *av[])
 	    sprintf(buff, ":reject::");
 	    break;
 	case CTnntp:
-	    sprintf(buff, ":nntp:%d:%s", Now.time - cp->LastActive, (cp->MaxCnx > 0 && cp->ActiveCnx == 0) ? "paused" : "");
+	    sprintf(buff, ":nntp:%ld:%s", Now.time - cp->LastActive, (cp->MaxCnx > 0 && cp->ActiveCnx == 0) ? "paused" : "");
 	    break;
 	case CTlocalconn:
 	    sprintf(buff, ":localconn::");
