@@ -1,4 +1,4 @@
-/*  $Id: startinnfeed.c,v 1.14 1999/12/05 00:39:27 rra Exp $
+/*  $Id: startinnfeed.c,v 1.14.2.1 2003/02/02 20:50:06 rra Exp $
 **
 **  Raise system limits and exec innfeed.
 **
@@ -130,8 +130,8 @@ main(int argc, char *argv[])
             if (innconf->rlimitnofile < rl.rlim_cur)
                 rl.rlim_cur = innconf->rlimitnofile;
             if (setrlimit(RLIMIT_NOFILE, &rl) == -1)
-                syslog(LOG_WARNING, "can't setrlimit(NOFILE, %d): %m",
-                       rl.rlim_cur);
+                syslog(LOG_WARNING, "can't setrlimit(NOFILE, %lu): %m",
+                       (unsigned long) rl.rlim_cur);
         }
     }
 # endif /* RLIMIT_NOFILE */
