@@ -1,4 +1,4 @@
-/*  $Id: date.c,v 1.4.2.1 2000/06/24 10:35:04 rra Exp $
+/*  $Id: date.c,v 1.4.2.2 2003/02/02 20:50:55 rra Exp $
 **
 **  Date parsing and conversion routines.
 **
@@ -96,7 +96,7 @@ makedate(time_t clock, BOOL local, char *buff, size_t buflen)
     long tz_offset;
     int tz_hour_offset, tz_min_offset, tz_sign;
     size_t date_length;
-    char *tz_name;
+    const char *tz_name;
 
     /* Make sure the buffer is large enough. */
     if (buflen < DATE_LENGTH + 1) return FALSE;
