@@ -1,4 +1,4 @@
-/*  $Id: fseeko.c 3680 2000-07-29 22:54:52Z rra $
+/*  $Id: fseeko.c,v 1.1.2.2 2000/08/05 22:49:27 rra Exp $
 **
 **  Replacement for a missing fseeko.
 **
@@ -14,6 +14,9 @@
 #include "clibrary.h"
 #include <errno.h>
 
+/* Make sure we get the system fseek (clibrary.h #defines it to fseeko). */
+#undef fseek
+
 #if HAVE_LARGE_FPOS_T
 
 int
