@@ -1,15 +1,14 @@
-/*  $Id: radix32.c 7585 2006-11-21 09:37:51Z eagle $
+/*  $Revision: 1.2 $
 **
 **  Radix-32 strings divide a number into five-bit nibbles and use the
 **  alphabet 0..9a..v to represent 0..32.
 */
-
-#include "config.h"
+#include <stdio.h>
+#include <sys/types.h>
+#include "configdata.h"
 #include "clibrary.h"
 #include <time.h>
 
-#include "inn/libinn.h"
-
 
 static char	ALPHABET[] =
     "0123456789abcdefghijklmnopqrstuv";
@@ -49,10 +48,10 @@ void Radix32(unsigned long l, char *buff)
 */
 unsigned long
 Decode32(p)
-    char		*p;
+    register char		*p;
 {
-    unsigned long	l;
-    char		*cp;
+    register unsigned long	l;
+    register char		*cp;
 
     for (l = 0; *p; p++) {
 	if ((cp = strchr(ALPHABET, *p)) == NULL)
