@@ -1,4 +1,4 @@
-/*  $Revision: 1.50.2.12 $
+/*  $Revision: 1.50.2.14 $
 **
 **  Check article, send it to the local server.
 */
@@ -77,6 +77,7 @@ HEADER	Table[] = {
 #define _xcomplaintsto	22
     {   "NNTP-Posting-Date",	FALSE, HTstd },
 #define _nntppostdate	23
+    {   "Injector-Info",        FALSE,  HTstd },
     {	"Xref",			FALSE,	HTstd },
     {	"Summary",		TRUE,	HTstd },
     {	"Keywords",		TRUE,	HTstd },
@@ -667,8 +668,7 @@ STATIC STRING ValidNewsgroups(char *hdr, char **modgroup)
     if ((p = strtok(groups, NGSEPS)) == NULL)
 	return "Can't parse newsgroups line";
 
-    /* Don't mail article if just checking Followup-To line. */
-    approved = HDR(_approved) != NULL || modgroup == NULL;
+    approved = HDR(_approved) != NULL;
 
     Error[0] = '\0';
     FoundOne = FALSE;
@@ -709,7 +709,7 @@ STATIC STRING ValidNewsgroups(char *hdr, char **modgroup)
 	case NF_FLAG_MODERATED:
 	    if (approved && !PERMaccessconf->allowapproved) {
 		(void)sprintf(Error, "You are not allowed to approve postings");
-	    } else if (!approved && !*modgroup) {
+	    } else if (!approved && modgroup != NULL && !*modgroup) {
 		*modgroup = COPY(p);
 	    }
 	    break;
