@@ -1,4 +1,4 @@
-/*  $Id: ov3.c,v 1.20.2.11 2002/03/31 22:51:01 rra Exp $
+/*  $Id: ov3.c,v 1.20.2.12 2003/02/02 21:42:53 rra Exp $
 **
 **  Indexed overview method.
 */
@@ -706,7 +706,7 @@ STATIC BOOL OV3addrec(GROUPENTRY *ge, GROUPHANDLE *gh, int artnum, TOKEN token,
     } else {
 	base = ge->base;
 	if (ge->base > artnum) {
-	    syslog(L_ERROR, "tradindexed: could not add %s:%d, base == %d", gh->group, artnum, ge->base);
+	    syslog(L_ERROR, "tradindexed: could not add %s:%d, base == %lu", gh->group, artnum, ge->base);
 	    return FALSE;
 	}
     }
