@@ -1,4 +1,4 @@
-/*  $Id: timehash.c,v 1.34.2.2 2001/02/03 07:28:53 rra Exp $
+/*  $Id: timehash.c,v 1.34.2.3 2003/02/02 21:42:55 rra Exp $
 **
 **  Timehash based storage method.
 */
@@ -156,7 +156,7 @@ TOKEN timehash_store(const ARTHANDLE article, const STORAGECLASS class) {
     }
     if (i == 0x10000) {
 	SMseterror(SMERR_UNDEFINED, NULL);
-	syslog(L_ERROR, "timehash: all sequence numbers for the time and class are reserved %d %d", now, class);
+	syslog(L_ERROR, "timehash: all sequence numbers for the time and class are reserved %ld %d", now, class);
 	token.type = TOKEN_EMPTY;
 	DISPOSE(path);
 	return token;
