@@ -1,4 +1,4 @@
-/*  $Id: tradspool.c,v 1.23.2.10 2002/11/09 19:54:53 rra Exp $
+/*  $Id: tradspool.c,v 1.23.2.11 2003/02/02 21:42:55 rra Exp $
 **
 **  Storage manager module for traditional spool format.
 */
@@ -188,7 +188,7 @@ AddNG(char *ng, unsigned long number) {
 			nextnode = &curnode->left;
 		    } else {
 			/* Error, same number is already in NGtree (shouldn't happen!) */
-			syslog(L_ERROR, "tradspool: AddNG: duplicate newsgroup number in NGtree: %d(%s)", number, p);
+			syslog(L_ERROR, "tradspool: AddNG: duplicate newsgroup number in NGtree: %lu(%s)", number, p);
 			return;
 		    }
 		}
